@@ -1,3 +1,5 @@
+import LibHanger.Library.uwLogger as Logger
+from LibHanger.Library.uwConfig import cmnConfig
 
 class globalValues:
 
@@ -40,3 +42,15 @@ class globalValues:
 
 # インスタンス生成(import時に実行される)
 gv = globalValues()
+
+def configer(__file__):
+    
+    # 共通設定(ノーマル)
+    ccfg = cmnConfig()
+    ccfg.getConfig(__file__, 'TestConfig')
+
+    # ロガー設定
+    Logger.setting(ccfg)
+
+    # 共通設定
+    gv.config = ccfg
