@@ -1,4 +1,3 @@
-from codecs import register_error
 import inspect
 import pandas as pd
 import copy
@@ -8,7 +7,7 @@ from enum import Enum
 from sqlalchemy.exc import SQLAlchemyError
 from sqlalchemy.sql.elements import BinaryExpression
 from sqlalchemy import and_, or_
-from sqlalchemy import asc,desc
+from sqlalchemy import asc
 from LibHanger.Models.fields import fields
 from LibHanger.Library.DataAccess.Base.uwDataAccess import uwDataAccess
 from LibHanger.Library.uwDeclare import uwDeclare as en
